@@ -17,9 +17,9 @@
 ;; Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 ;; Author: zk_phi
-;; URL: http://hins11.yu-yake.com/
-;; Package-Version: 20260218.1909
-;; Package-Revision: d663045c290f
+;; URL: http://zk-phi.github.io/
+;; Package-Version: 20260301.1008
+;; Package-Revision: 0d5805328539
 
 ;;; Commentary:
 
@@ -41,13 +41,14 @@
 ;; 1.1.2 add darwin support (mac os x)
 ;; 1.2.0 add paging feature
 ;; 1.2.1 fix sparkline cache initialization for Emacs 28+
+;; 1.2.2 use XPM images by default to workaround XBM rendering issues in Emacs 29+
 
 ;;; Code:
 
 (require 'battery)
 (require 'ring)
 
-(defconst symon-version "1.2.1")
+(defconst symon-version "1.2.2")
 
 (defgroup symon nil
   "tiny graphical system monitor"
@@ -115,9 +116,7 @@ smaller. *set this option BEFORE enabling `symon-mode'.*"
   "type of sparklines."
   :group 'symon)
 
-;; some darwin builds cannot render xbm images (foreground color is
-;; always black), so convert to xpm before rendering.
-(defcustom symon-sparkline-use-xpm (eq system-type 'darwin)
+(defcustom symon-sparkline-use-xpm t
   "when non-nil, convert sparklines to xpm from xbm before
 rendering."
   :group 'symon)
